"""All kinds of algorithms."""

__author__ = "pablo"

from .commands import *
